@@ -184,11 +184,10 @@ class hexagon_grid:
                                 gpd.overlay(gdf.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
                                             datax, how='intersection'),
                                 how = 'union')[['geometry']].copy()
+        if final_hexa.crs ==None:
+            final_hexa.crs ={'init': 'epsg:4326'}
         if hexagon_dis == True:
-            final_hexan = final_hexa.drop_duplicates(["geometry"])
-            pdf = gpd.overlay(gdf, final_hexan, how = 'union')
-            check_topology(pdf)
-            self.geosolution = pdf
+            self.geosolution = final_hexa
         else:
             if self.area_threshold == None:
                 area_thres = (spacing*spacing)*0.33
